Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CSV ¶ added in v1.6.6
type CSV string
CSV is a string with comma-separated values.
type OnOff ¶
type OnOff string
OnOff represents a setting that is on (true) or off (false) or undefined.
type Percentage ¶
type Percentage string
Percentage represents a percentage.
func (*Percentage) Int ¶
func (p *Percentage) Int() int
Int returns the integer part of a percentage.
func (*Percentage) Set ¶
func (p *Percentage) Set(v string) error
Set will update the value of a percentage type if the value can be parsed as a float, otherwise an error is returned.
func (*Percentage) String ¶
func (p *Percentage) String() string
func (*Percentage) Type ¶
func (p *Percentage) Type() string
Type returns a desccription of the percentage type.
Click to show internal directories.
Click to hide internal directories.